# Contribution guidelines

## Developer Workstation Setup

1. install Kafka https://kafka.apache.org/quickstart
1. install Redis https://redis.io/topics/quickstart
1. clone the kirby repository `git clone git@github.com:adimian/kirby.git`

## Useful Links

- Source: http://github.com/adimian/kirby 
- Issues: http://github.com/adimian/kirby/issues
- Documentation: http://kirby.readthedocs.io

## Writing Documentation

.. todo:: write this
